@@ -132,7 +132,6 @@
   return(CAA + (1/oneSinvone) - 2 * sum(w * CiA))
 }
 
-
 "nearloc" <- function(points, locations, positions=FALSE)
 {
   if(!is.data.frame(points) && is.list(points)){
@@ -149,10 +148,10 @@
     locations <- matrix(unlist(locations[1:2]), ncol=2)
   if(ncol(locations) != 2)
     stop("locations must be a matrix, data.frame, or list")
-  ind <- apply(loccoords(points, locations),1,which.min)
+  ind <- apply(loccoords(points, locations), 1, which.min)
   if(positions)
     return(ind)
-  res <- locations[apply(loccoords(points, locations),1,which.min),]
+  res <- locations[apply(loccoords(points, locations), 1, which.min),]
   rownames(res) <- ind
   if(backtolist){
     res <- list(res[,1], res[,2])
@@ -161,36 +160,6 @@
   return(res)
 }
 
-"cite.geoR" <- function()
-{
-    cat("\n")
-    cat("To cite geoR in publications, use\n\n")
-    msg <- "RIBEIRO Jr., P.J. & DIGGLE, P.J. (2001) geoR: A package for geostatistical analysis. R-NEWS, Vol 1, No 2, 15-18. ISSN 1609-3631."
-    writeLines(strwrap(msg, prefix = "  "))
-    cat("\n")
-    msg <- paste("Please cite geoR when using it for data analysis!")
-    writeLines(strwrap(msg))
-    cat("\nA BibTeX entry for LaTeX users is\n\n")
-    cat("  @Article{,\n")
-    cat("     title	   = {{geoR}: a package for geostatistical analysis},\n")
-    cat("     author        = {Ribeiro Jr., P.J. and Diggle, P.J.},\n")
-    cat("     journal       = {R-NEWS},\n")
-    cat("     year	   = {2001},\n")
-    cat("     volume	   = {1},\n")
-    cat("     number	   = {2},\n")
-    cat("     pages	   = {15--18},\n")
-    cat("     issn          = {1609-3631},\n")
-    cat("     url           = {http://cran.R-project.org/doc/Rnews}\n")
-    cat("   }\n\n")
-}
-
-#geoR.options <- function(messages = TRUE, ...)
-#{
-#  res <- list(...)
-#  res$messages <- messages
-#  .geoR.options <<- res
-#  return(invisible())
-#}
 
 "coords2coords" <-
   function(coords, xlim, ylim, xlim.ori, ylim.ori)
